@@ -1,9 +1,9 @@
+from .constants import *
 from .core import *
-from .model import *
-from .constant import *
+from .exceptions import *
+from .models import *
 
 
-__version__ = "0.0.14"
 __all__ = (
     "BASE_URL",
     "HEADERS",
@@ -13,6 +13,12 @@ __all__ = (
     "Badge",
     "Author",
     "SearchResult",
+    "TopicNotFound",
+    "EntryNotFound",
+    "AuthorNotFound",
+    "PageNotFound",
+    "SearchResultNotFound",
+    "ElementNotFound",
     "get_topic",
     "get_entry",
     "get_author",
